#
# spec file for package linux-atm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if %{undefined _firmwaredir}
%define _firmwaredir /lib/firmware
%endif
%global sover   1
Name:           linux-atm
Version:        2.5.2
Release:        9.1
Summary:        Tools for ATM
License:        BSD-3-Clause AND GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Networking/Other
URL:            http://linux-atm.sourceforge.net/
Source0:        http://downloads.sourceforge.net/project/%{name}/%{name}/%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM linux-atm-2.5.2_fdleak.patch
Patch0:         linux-atm-2.5.2_fdleak.patch
# PATCH-FIX-UPSTREAM linux-atm-2.5.2_implicit-fortify-decl.patch -- fix implicit declarations
Patch1:         linux-atm-2.5.2_implicit-fortify-decl.patch
# PATCH-FIX-UPSTREAM linux-atm-2.5.2-fix-header-conflict.patch -- avoid conflict with kernel headers
Patch2:         linux-atm-2.5.2-fix-header-conflict.patch
# PATCH-FIX-UPSTREAM linux-atm-2.5.2-remove-headers-crude-hack.patch -- Remove headers crude hack
Patch3:         linux-atm-2.5.2-remove-headers-crude-hack.patch
# PATCH-FIX-UPSTREAM fix-build-after-y2038-changes-in-glibc.patch -- fix build after y2038 changes in glibc
Patch4:         fix-build-after-y2038-changes-in-glibc.patch
# PATCH-FIX-UPSTREAM linux-atm-C99.patch -- fix passing wrong type to accept
Patch5:         linux-atm-C99.patch

BuildRequires:  autoconf
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  glibc-devel
BuildRequires:  libtool

%description
Tools to support ATM (Asynchronous Transfer Mode) networking.

%package -n libatm%{sover}
Summary:        Libraries for ATM
Group:          System/Libraries

%description -n libatm%{sover}
Libraries for ATM (Asynchronous Transfer Mode) networking.

%package devel
Summary:        Development for ATM
Group:          Development/Libraries/C and C++
Requires:       libatm%{sover} = %{version}

%description devel
Libraries and header files for ATM (Asynchronous Transfer Mode)
networking.

%prep
%autosetup -p1

%build
sed 's|/lib/firmware|%{_firmwaredir}|g' -i src/extra/Makefile.am
autoreconf -fiv
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libatm%{sover} -p /sbin/ldconfig
%postun -n libatm%{sover} -p /sbin/ldconfig

%files
%doc README AUTHORS ChangeLog NEWS THANKS BUGS
%config(noreplace) %{_sysconfdir}/atmsigd.conf
%config(noreplace) %{_sysconfdir}/hosts.atm
%{_bindir}/*
%{_sbindir}/*
%{_firmwaredir}/*
%{_mandir}/man*/*%{?ext_man}

%files -n libatm%{sover}
%license COPYING COPYING.GPL COPYING.LGPL
%{_libdir}/libatm.so.%{sover}*

%files devel
%{_includedir}/atm*.h
%{_libdir}/libatm.so

%changelog
* Fri Jul 12 2024 Martin Jambor <mjambor@suse.com>
- Add linux-atm-C99.patch to fix a wrong type being passed to
  functionaccept which violates C99 rules and causes compilation to
  fail with GCC 14 (and IMHO can cause wrong behavior on big-endian
  systems).  [boo#1221006]
* Wed Jun  2 2021 Callum Farmer <gmbr3@opensuse.org>
- Use %%_firmwaredir
* Fri Dec  6 2019 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file a bit:
  * Move licnse to library package
  * Use more of new macros for building
* Thu Jul 11 2019 Jiri Slaby <jslaby@suse.com>
- add fix-build-after-y2038-changes-in-glibc.patch
* Wed Jan  9 2019 Jiri Slaby <jslaby@suse.com>
- add linux-atm-2.5.2-remove-headers-crude-hack.patch
- switch from %%doc to %%license for licenses
* Mon Oct 17 2016 schwab@suse.de
- linux-atm-2.5.2-fix-header-conflict.patch: avoid conflict with kernel
  headers
* Thu Jan 23 2014 aj@ajaissle.de
- Cleanup spec file, remove %%clean section
- Updated to 2.5.2
- Removed linux-atm-2.5.0.diff (in mainline)
- Removed linux-atm-2.5.0-include.patch (in mainline)
- Rebased linux-atm-2.5.0-fdleak.patch as linux-atm-2.5.2_fdleak.patch
- Added linux-atm-2.5.2_implicit-fortify-decl.patch to fix implicit declarations
* Tue Apr 16 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Fri Feb  1 2013 coolo@suse.com
- update license to new format
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Tue Nov  2 2010 coolo@novell.com
- fix requires after rename
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
- Shared library policy: rename linux-atm-lib -> libatm
* Sat Oct 10 2009 crrodriguez@opensuse.org
- fix fdleak [bnc#544223]
- remove static libraries and "la" files
* Fri Jun 12 2009 coolo@novell.com
- fix build with glibc 2.10
* Thu Mar 29 2007 rguenther@suse.de
- add bison and flex BuildRequires
* Fri Mar 23 2007 ssommer@suse.de
- fix build with newer kernel headers
* Sat May 27 2006 schwab@suse.de
- Don't strip binaries.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Apr 22 2005 arvin@suse.de
- updated to latest CVS
* Wed Apr 20 2005 arvin@suse.de
- updated to 2.5.0 CVS + my GCC 4.0 and other patches
* Mon Apr 18 2005 arvin@suse.de
- some (but not all) gcc 4.0 fixes
* Tue Apr 20 2004 arvin@suse.de
- removed some compile warnings
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Sat Jul 19 2003 meissner@suse.de
- drop 1 line from ltconfig, so it builds shared libs on ppc64.
* Mon May 26 2003 arvin@suse.de
- split package into linux-atm, linux-atm-lib and linux-atm-devel
- include all programs/files to make rpm v4 happy
* Thu Apr 18 2002 kukuk@suse.de
- Add suse_update_config for x86_64
* Tue Jan  8 2002 arvin@suse.de
- include some documentation in the package
* Mon Jan  7 2002 arvin@suse.de
- initial package for atm
